# forestvpn_auth_api.api.AuthApi

## Load the API package
```dart
import 'package:forestvpn_auth_api/api.dart';
```

All URIs are relative to *https://auth.forestvpn.com/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**introspect**](AuthApi.md#introspect) | **POST** /introspect/ | Token introspection
[**login**](AuthApi.md#login) | **POST** /login/ | Login
[**profileGet**](AuthApi.md#profileget) | **GET** /profile/ | Get authenticated user's profile
[**refreshToken**](AuthApi.md#refreshtoken) | **POST** /token/ | Refresh access token
[**registrationSessionCreate**](AuthApi.md#registrationsessioncreate) | **POST** /registration/ | Create user registration session
[**registrationSessionValidate**](AuthApi.md#registrationsessionvalidate) | **PUT** /registration/{sessionId}/validate/ | Send email validation message
[**registrationSessionVerify**](AuthApi.md#registrationsessionverify) | **PUT** /registration/{sessionId}/verify/ | Verify email address
[**signIn**](AuthApi.md#signin) | **POST** /signin/ | Sign In
[**signInResend**](AuthApi.md#signinresend) | **POST** /signin/{sessionId}/resend/ | Resend OTP for Sign In
[**signInVerify**](AuthApi.md#signinverify) | **POST** /signin/{sessionId}/verify/ | One time code verification
[**signUp**](AuthApi.md#signup) | **POST** /signup/ | Sign Up
[**signUpResend**](AuthApi.md#signupresend) | **POST** /signup/{sessionId}/resend/ | Resend OTP for Sign Up
[**signUpVerify**](AuthApi.md#signupverify) | **POST** /signup/{sessionId}/verify/ | Sign Up verification


# **introspect**
> IntrospectionResponse introspect(request)

Token introspection

The introspection endpoint allows to check if a token (both refresh and access) is active or not.

### Example 
```dart
import 'package:forestvpn_auth_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

final api_instance = AuthApi();
final request = IntrospectionRequest(); // IntrospectionRequest | 

try { 
    final result = api_instance.introspect(request);
    print(result);
} catch (e) {
    print('Exception when calling AuthApi->introspect: $e\n');
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **request** | [**IntrospectionRequest**](IntrospectionRequest.md)|  | 

### Return type

[**IntrospectionResponse**](IntrospectionResponse.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **login**
> TokenResponse login(request)

Login

### Example 
```dart
import 'package:forestvpn_auth_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

final api_instance = AuthApi();
final request = UserLoginRequest(); // UserLoginRequest | 

try { 
    final result = api_instance.login(request);
    print(result);
} catch (e) {
    print('Exception when calling AuthApi->login: $e\n');
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **request** | [**UserLoginRequest**](UserLoginRequest.md)|  | 

### Return type

[**TokenResponse**](TokenResponse.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **profileGet**
> UserProfile profileGet()

Get authenticated user's profile

### Example 
```dart
import 'package:forestvpn_auth_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

final api_instance = AuthApi();

try { 
    final result = api_instance.profileGet();
    print(result);
} catch (e) {
    print('Exception when calling AuthApi->profileGet: $e\n');
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**UserProfile**](UserProfile.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **refreshToken**
> TokenResponse refreshToken(request)

Refresh access token

### Example 
```dart
import 'package:forestvpn_auth_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

final api_instance = AuthApi();
final request = TokenRequest(); // TokenRequest | 

try { 
    final result = api_instance.refreshToken(request);
    print(result);
} catch (e) {
    print('Exception when calling AuthApi->refreshToken: $e\n');
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **request** | [**TokenRequest**](TokenRequest.md)|  | 

### Return type

[**TokenResponse**](TokenResponse.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **registrationSessionCreate**
> UserRegistrationResponse registrationSessionCreate(request)

Create user registration session

### Example 
```dart
import 'package:forestvpn_auth_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

final api_instance = AuthApi();
final request = UserRegistrationRequest(); // UserRegistrationRequest | 

try { 
    final result = api_instance.registrationSessionCreate(request);
    print(result);
} catch (e) {
    print('Exception when calling AuthApi->registrationSessionCreate: $e\n');
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **request** | [**UserRegistrationRequest**](UserRegistrationRequest.md)|  | 

### Return type

[**UserRegistrationResponse**](UserRegistrationResponse.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **registrationSessionValidate**
> registrationSessionValidate(sessionId)

Send email validation message

### Example 
```dart
import 'package:forestvpn_auth_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

final api_instance = AuthApi();
final sessionId = sessionId_example; // String | Registration Session ID

try { 
    api_instance.registrationSessionValidate(sessionId);
} catch (e) {
    print('Exception when calling AuthApi->registrationSessionValidate: $e\n');
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **sessionId** | **String**| Registration Session ID | 

### Return type

void (empty response body)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **registrationSessionVerify**
> TokenResponse registrationSessionVerify(sessionId, verifyRequest)

Verify email address

Verify email address

### Example 
```dart
import 'package:forestvpn_auth_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

final api_instance = AuthApi();
final sessionId = sessionId_example; // String | Registration Session ID
final verifyRequest = UserRegistrationVerifyRequest(); // UserRegistrationVerifyRequest | 

try { 
    final result = api_instance.registrationSessionVerify(sessionId, verifyRequest);
    print(result);
} catch (e) {
    print('Exception when calling AuthApi->registrationSessionVerify: $e\n');
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **sessionId** | **String**| Registration Session ID | 
 **verifyRequest** | [**UserRegistrationVerifyRequest**](UserRegistrationVerifyRequest.md)|  | 

### Return type

[**TokenResponse**](TokenResponse.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **signIn**
> SignInResponse signIn(request)

Sign In

### Example 
```dart
import 'package:forestvpn_auth_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

final api_instance = AuthApi();
final request = SignInRequest(); // SignInRequest | 

try { 
    final result = api_instance.signIn(request);
    print(result);
} catch (e) {
    print('Exception when calling AuthApi->signIn: $e\n');
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **request** | [**SignInRequest**](SignInRequest.md)|  | 

### Return type

[**SignInResponse**](SignInResponse.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **signInResend**
> signInResend(sessionId)

Resend OTP for Sign In

### Example 
```dart
import 'package:forestvpn_auth_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

final api_instance = AuthApi();
final sessionId = sessionId_example; // String | Sign In Session ID

try { 
    api_instance.signInResend(sessionId);
} catch (e) {
    print('Exception when calling AuthApi->signInResend: $e\n');
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **sessionId** | **String**| Sign In Session ID | 

### Return type

void (empty response body)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **signInVerify**
> TokenResponse signInVerify(sessionId, request)

One time code verification

### Example 
```dart
import 'package:forestvpn_auth_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

final api_instance = AuthApi();
final sessionId = sessionId_example; // String | Sign In Session ID
final request = SignInVerifyRequest(); // SignInVerifyRequest | 

try { 
    final result = api_instance.signInVerify(sessionId, request);
    print(result);
} catch (e) {
    print('Exception when calling AuthApi->signInVerify: $e\n');
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **sessionId** | **String**| Sign In Session ID | 
 **request** | [**SignInVerifyRequest**](SignInVerifyRequest.md)|  | 

### Return type

[**TokenResponse**](TokenResponse.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **signUp**
> SignUpResponse signUp(request)

Sign Up

### Example 
```dart
import 'package:forestvpn_auth_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

final api_instance = AuthApi();
final request = SignUpRequest(); // SignUpRequest | 

try { 
    final result = api_instance.signUp(request);
    print(result);
} catch (e) {
    print('Exception when calling AuthApi->signUp: $e\n');
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **request** | [**SignUpRequest**](SignUpRequest.md)|  | 

### Return type

[**SignUpResponse**](SignUpResponse.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **signUpResend**
> signUpResend(sessionId)

Resend OTP for Sign Up

### Example 
```dart
import 'package:forestvpn_auth_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

final api_instance = AuthApi();
final sessionId = sessionId_example; // String | Sign In Session ID

try { 
    api_instance.signUpResend(sessionId);
} catch (e) {
    print('Exception when calling AuthApi->signUpResend: $e\n');
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **sessionId** | **String**| Sign In Session ID | 

### Return type

void (empty response body)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **signUpVerify**
> TokenResponse signUpVerify(sessionId, request)

Sign Up verification

### Example 
```dart
import 'package:forestvpn_auth_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

final api_instance = AuthApi();
final sessionId = sessionId_example; // String | Sign Up Session ID
final request = SignUpVerifyRequest(); // SignUpVerifyRequest | 

try { 
    final result = api_instance.signUpVerify(sessionId, request);
    print(result);
} catch (e) {
    print('Exception when calling AuthApi->signUpVerify: $e\n');
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **sessionId** | **String**| Sign Up Session ID | 
 **request** | [**SignUpVerifyRequest**](SignUpVerifyRequest.md)|  | 

### Return type

[**TokenResponse**](TokenResponse.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

